summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--build.bat2
-rwxr-xr-xstandalone/windows/build-simple.sh6
2 files changed, 4 insertions, 4 deletions
diff --git a/build.bat b/build.bat
index 52d03e0e2..268a02835 100644
--- a/build.bat
+++ b/build.bat
@@ -1 +1 @@
-C:\CYGWIN\BIN\SH.EXE standalone/windows/build-simple.sh
+SH.EXE standalone/windows/build-simple.sh
diff --git a/standalone/windows/build-simple.sh b/standalone/windows/build-simple.sh
index ade21ce6d..2c9aeb915 100755
--- a/standalone/windows/build-simple.sh
+++ b/standalone/windows/build-simple.sh
@@ -4,10 +4,10 @@
set -e
set -x
-# Path to the Haskell Platform.
-HP="/c/Program Files/Haskell Platform/2013.2.0.0"
+# Path to the Haskell Platform. (As mingw sh sees it)
+HP="/c/Program Files/Haskell Platform/2014.2.0.0"
-PATH="$HP/bin:$HP/lib/extralibs/bin:$PATH"
+PATH="$HP/bin:$HP/mingw/bin:$HP/lib/extralibs/bin:$PATH"
# Run a command with the cygwin environment available.
# However, programs not from cygwin are preferred.